==> js.tinymce-4.0.12.zip: js.tinymce-4.0.12/js/tinymce/resources/langs/de_AT.js <==
tinymce.addI18n('de_AT',{
"Cut": "Ausschneiden",
"Header 2": "\u00dcberschrift 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Ihr Browser unterst\u00fctzt keinen direkten Zugriff auf die Zwischenablage. Bitte nutzen Sie die Tastaturk\u00fcrzel Strg+X\/C\/V stattdessen.",
"Div": "Block (div)",
"Paste": "Einf\u00fcgen",
"Close": "Schlie\u00dfen",
"Font Family": "Schriftart",
"Pre": "Vorformatierter Text (pre)",
"Align right": "Rechtsb\u00fcndig",
"New document": "Neues Dokument",
"Blockquote": "Zitat (blockquote)",
"Numbered list": "Sortierte Liste",
"Increase indent": "Einr\u00fccken",
"Formats": "Formate",
"Headers": "\u00dcberschriften",
"Select all": "Alles ausw\u00e4hlen",
"Header 3": "\u00dcberschrift 3",
"Blocks": "Bl\u00f6cke",
"Undo": "R\u00fcckg\u00e4ngig",
"Strikethrough": "Durchgestrichen",
"Bullet list": "Unsortierte Liste",
"Header 1": "\u00dcberschrift 1",
"Superscript": "Hochgestellt",
"Clear formatting": "Formatierungen zur\u00fccksetzen",
"Font Sizes": "Schriftgr\u00f6\u00dfen",
"Subscript": "Tiefgestellt",
"Header 6": "\u00dcberschrift 6",
"Redo": "Wiederholen",
"Paragraph": "Absatz (p)",
"Ok": "Ok",
"Bold": "Fett",
"Code": "Code (code)",
"Italic": "Kursiv",
"Align center": "Zentriert",
"Header 5": "\u00dcberschrift 5",
"Decrease indent": "Ausr\u00fccken",
"Header 4": "\u00dcberschrift 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Alle Texte werden nun ohne Formatierung eingef\u00fcgt, bis diese Einstellung wieder ge\u00e4ndert wird.",
"Underline": "Unterstrichen",
"Cancel": "Abbrechen",
"Justify": "Blocksatz",
"Inline": "Inline",
"Copy": "Kopieren",
"Align left": "Linksb\u00fcndig",
"Visual aids": "Hilfslinien und unsichtbare Elemente einblenden",
"Lower Greek": "Griechische Kleinbuchstaben",
"Square": "Quadrat",
"Default": "Standard",
"Lower Alpha": "Kleinbuchstaben",
"Circle": "Kreis",
"Disc": "Gef\u00fcllter Kreis",
"Upper Alpha": "Gro\u00dfbuchstaben",
"Upper Roman": "R\u00f6mische Zahlen (Gro\u00dfbuchstaben)",
"Lower Roman": "R\u00f6mische Zahlen (Kleinbuchstaben)",
"Name": "Name",
"Anchor": "Anker",
"You have unsaved changes are you sure you want to navigate away?": "Sie haben ungespeicherte \u00c4nderungen. Sind Sie sicher, dass Sie die Seite verlassen wollen?",
"Restore last draft": "Letzten Entwurf wiederherstellen.",
"Special character": "Sonderzeichen",
"Source code": "Quelltext",
"Right to left": "Rechts nach links",
"Left to right": "Links nach rechts",
"Emoticons": "Emoticons",
"Robots": "Suchmaschinen",
"Document properties": "Dokumenteigenschaften",
"Title": "Titel",
"Keywords": "Schl\u00fcsselw\u00f6rter",
"Encoding": "Enkodierung",
"Description": "Beschreibung",
"Author": "Autor",
"Fullscreen": "Vollbild",
"Horizontal line": "Horizontale Trennlinie",
"Horizontal space": "Horizontaler Abstand",
"Insert\/edit image": "Bild einf\u00fcgen\/bearbeiten",
"General": "Allgemein",
"Advanced": "Erweitert",
"Source": "Adresse",
"Border": "Rahmen",
"Constrain proportions": "Seitenverh\u00e4ltnis beibehalten",
"Vertical space": "Vertikaler Abstand",
"Image description": "Bildbeschreibung",
"Style": "Format",
"Dimensions": "Ausma\u00dfe",
"Insert image": "Bild einf\u00fcgen",
"Insert date\/time": "Zeit\/Datum einf\u00fcgen",
"Remove link": "Link entfernen",
"Url": "Url",
"Text to display": "Angezeigter Text",
"Anchors": "Anker",
"Insert link": "Link einf\u00fcgen",
"New window": "Neues Fenster",
"None": "Keine",
"Target": "Ziel",
"Insert\/edit link": "Link einf\u00fcgen\/bearbeiten",
"Insert\/edit video": "Video einf\u00fcgen\/bearbeiten",
"Poster": "Poster",
"Alternative source": "Alternative Quelle",
"Paste your embed code below:": "F\u00fcgen unten Sie Ihren Quellcode zum einbetten ein",
"Insert video": "Video einf\u00fcgen",
"Embed": "Einbetten",
"Nonbreaking space": "gesch\u00fctztes Leerzeichen",
"Page break": "Seitenumbruch",
"Paste as text": "Als Text einf\u00fcgen",
"Preview": "Vorschau",
"Print": "Drucken",
"Save": "Speichern",
"Could not find the specified string.": "Keine \u00dcbereinstimmung gefunden",
"Replace": "Ersetzen",
"Next": "N\u00e4chstes",
"Whole words": "Vollst\u00e4ndige W\u00f6rter",
"Find and replace": "Suchen und ersetzen",
"Replace with": "Ersetzen durch",
"Find": "Suchen",
"Replace all": "Alle ersetzen",
"Match case": "Gro\u00df-\/Kleinschreibung beachten",
"Prev": "Vorheriges",
"Spellcheck": "Rechtschreibung \u00fcberpr\u00fcfen",
"Finish": "Fertig",
"Ignore all": "Alle ignorieren",
"Ignore": "Ignorieren",
"Insert row before": "Neue Zeile oberhalb einf\u00fcgen",
"Rows": "Zeilen",
"Height": "H\u00f6he",
"Paste row after": "Zeile unterhalb einf\u00fcgen",
"Alignment": "Ausrichtung",
"Column group": "Spaltengruppe",
"Row": "Zeile",
"Insert column before": "Neue Spalte links einf\u00fcgen",
"Split cell": "Verbundene Zellen trennen",
"Cell padding": "Abstand innerhalb der Zellen",
"Cell spacing": "Zellenabstand",
"Row type": "Zeilentyp",
"Insert table": "Tabelle einf\u00fcgen",
"Body": "Tabellenk\u00f6rper",
"Caption": "Beschriftung der Tabelle",
"Footer": "Tabellenfu\u00df",
"Delete row": "Zeile l\u00f6schen",
"Paste row before": "Zeile oberhalb einf\u00fcgen",
"Scope": "Geltungsbereich",
"Delete table": "Tabelle l\u00f6schen",
"Header cell": "\u00dcberschrift",
"Column": "Spalte",
"Cell": "Zelle",
"Header": "Tabellen\u00fcberschrift",
"Cell type": "Zellentyp",
"Copy row": "Zeile kopieren",
"Row properties": "Zeileneigenschaften",
"Table properties": "Tabelleneigenschaften",
"Row group": "Zeilengruppe",
"Right": "Rechts",
"Insert column after": "Neue Spalte rechts einf\u00fcgen",
"Cols": "Spalten",
"Insert row after": "Neue Zeile unterhalb einf\u00fcgen",
"Width": "Breite",
"Cell properties": "Zelleneigenschaften",
"Left": "Links",
"Cut row": "Zeile ausschneiden",
"Delete column": "Spalte l\u00f6schen",
"Center": "Zentriert",
"Merge cells": "Zellen vereinen",
"Insert template": "Vorlage einf\u00fcgen",
"Templates": "Vorlagen",
"Background color": "Hintergrundfarbe",
"Text color": "Textfarbe",
"Show blocks": "Blockelemente einblenden",
"Show invisible characters": "Unsichtbare Zeichen einblenden",
"Words: {0}": "W\u00f6rter: {0}",
"Insert": "Einf\u00fcgen",
"File": "Datei",
"Edit": "Bearbeiten",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Dr\u00fccken Sie ALT-F9 f\u00fcr das Men\u00fc. Dr\u00fccken Sie ALT-F10 f\u00fcr die Werkzeugleiste. Dr\u00fccken Sie ALT-0 f\u00fcr Hilfe",
"Tools": "Extras",
"View": "Ansicht",
"Table": "Tabelle",
"Format": "Format"
});

==> js.tinymce-4.0.28.zip: js.tinymce-4.0.28/js/tinymce/resources/langs/de_AT.js <==
tinymce.addI18n('de_AT',{
"Cut": "Ausschneiden",
"Heading 5": "\u00dcberschrift 5",
"Header 2": "\u00dcberschrift 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Ihr Browser unterst\u00fctzt keinen direkten Zugriff auf die Zwischenablage. Bitte nutzen Sie die Tastaturk\u00fcrzel Strg+X\/C\/V stattdessen.",
"Heading 4": "\u00dcberschrift 4",
"Div": "Block (div)",
"Heading 2": "\u00dcberschrift 2",
"Paste": "Einf\u00fcgen",
"Close": "Schlie\u00dfen",
"Font Family": "Schriftart",
"Pre": "Vorformatierter Text (pre)",
"Align right": "Rechtsb\u00fcndig",
"New document": "Neues Dokument",
"Blockquote": "Zitat (blockquote)",
"Numbered list": "Sortierte Liste",
"Heading 1": "\u00dcberschrift 1",
"Headings": "\u00dcberschriften",
"Increase indent": "Einr\u00fccken",
"Formats": "Formate",
"Headers": "\u00dcberschriften",
"Select all": "Alles ausw\u00e4hlen",
"Header 3": "\u00dcberschrift 3",
"Blocks": "Bl\u00f6cke",
"Undo": "R\u00fcckg\u00e4ngig",
"Strikethrough": "Durchgestrichen",
"Bullet list": "Unsortierte Liste",
"Header 1": "\u00dcberschrift 1",
"Superscript": "Hochgestellt",
"Clear formatting": "Formatierungen zur\u00fccksetzen",
"Font Sizes": "Schriftgr\u00f6\u00dfen",
"Subscript": "Tiefgestellt",
"Header 6": "\u00dcberschrift 6",
"Redo": "Wiederholen",
"Paragraph": "Absatz (p)",
"Ok": "Ok",
"Bold": "Fett",
"Code": "Code (code)",
"Italic": "Kursiv",
"Align center": "Zentriert",
"Header 5": "\u00dcberschrift 5",
"Heading 6": "\u00dcberschrift 6",
"Heading 3": "\u00dcberschrift 3",
"Decrease indent": "Ausr\u00fccken",
"Header 4": "\u00dcberschrift 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Alle Texte werden nun ohne Formatierung eingef\u00fcgt, bis diese Einstellung wieder ge\u00e4ndert wird.",
"Underline": "Unterstrichen",
"Cancel": "Abbrechen",
"Justify": "Blocksatz",
"Inline": "Inline",
"Copy": "Kopieren",
"Align left": "Linksb\u00fcndig",
"Visual aids": "Hilfslinien und unsichtbare Elemente einblenden",
"Lower Greek": "Griechische Kleinbuchstaben",
"Square": "Quadrat",
"Default": "Standard",
"Lower Alpha": "Kleinbuchstaben",
"Circle": "Kreis",
"Disc": "Gef\u00fcllter Kreis",
"Upper Alpha": "Gro\u00dfbuchstaben",
"Upper Roman": "R\u00f6mische Zahlen (Gro\u00dfbuchstaben)",
"Lower Roman": "R\u00f6mische Zahlen (Kleinbuchstaben)",
"Name": "Name",
"Anchor": "Anker",
"You have unsaved changes are you sure you want to navigate away?": "Sie haben ungespeicherte \u00c4nderungen. Sind Sie sicher, dass Sie die Seite verlassen wollen?",
"Restore last draft": "Letzten Entwurf wiederherstellen.",
"Special character": "Sonderzeichen",
"Source code": "Quelltext",
"Right to left": "Rechts nach links",
"Left to right": "Links nach rechts",
"Emoticons": "Emoticons",
"Robots": "Suchmaschinen",
"Document properties": "Dokumenteigenschaften",
"Title": "Titel",
"Keywords": "Schl\u00fcsselw\u00f6rter",
"Encoding": "Enkodierung",
"Description": "Beschreibung",
"Author": "Autor",
"Fullscreen": "Vollbild",
"Horizontal line": "Horizontale Trennlinie",
"Horizontal space": "Horizontaler Abstand",
"Insert\/edit image": "Bild einf\u00fcgen\/bearbeiten",
"General": "Allgemein",
"Advanced": "Erweitert",
"Source": "Adresse",
"Border": "Rahmen",
"Constrain proportions": "Seitenverh\u00e4ltnis beibehalten",
"Vertical space": "Vertikaler Abstand",
"Image description": "Bildbeschreibung",
"Style": "Format",
"Dimensions": "Ausma\u00dfe",
"Insert image": "Bild einf\u00fcgen",
"Insert date\/time": "Zeit\/Datum einf\u00fcgen",
"Remove link": "Link entfernen",
"Url": "Url",
"Text to display": "Angezeigter Text",
"Anchors": "Anker",
"Insert link": "Link einf\u00fcgen",
"New window": "Neues Fenster",
"None": "Keine",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Die eingegebene URL scheint eine externe Web-Adresse zu sein. Soll das notwendige \"http:\/\/\"-Pr\u00e4fix hinzugef\u00fcgt werden?",
"Target": "Ziel",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Die eingegebene URL scheint eine E-Mail-Adresse zu sein. Soll das notwendige \"mailto:\"-Pr\u00e4fix hinzugef\u00fcgt werden?",
"Insert\/edit link": "Link einf\u00fcgen\/bearbeiten",
"Insert\/edit video": "Video einf\u00fcgen\/bearbeiten",
"Poster": "Poster",
"Alternative source": "Alternative Quelle",
"Paste your embed code below:": "F\u00fcgen unten Sie Ihren Quellcode zum einbetten ein",
"Insert video": "Video einf\u00fcgen",
"Embed": "Einbetten",
"Nonbreaking space": "gesch\u00fctztes Leerzeichen",
"Page break": "Seitenumbruch",
"Paste as text": "Als Text einf\u00fcgen",
"Preview": "Vorschau",
"Print": "Drucken",
"Save": "Speichern",
"Could not find the specified string.": "Keine \u00dcbereinstimmung gefunden",
"Replace": "Ersetzen",
"Next": "N\u00e4chstes",
"Whole words": "Vollst\u00e4ndige W\u00f6rter",
"Find and replace": "Suchen und ersetzen",
"Replace with": "Ersetzen durch",
"Find": "Suchen",
"Replace all": "Alle ersetzen",
"Match case": "Gro\u00df-\/Kleinschreibung beachten",
"Prev": "Vorheriges",
"Spellcheck": "Rechtschreibung \u00fcberpr\u00fcfen",
"Finish": "Fertig",
"Ignore all": "Alle ignorieren",
"Ignore": "Ignorieren",
"Add to Dictionary": "Zum W\u00f6rterbuch hinzuf\u00fcgen",
"Insert row before": "Neue Zeile oberhalb einf\u00fcgen",
"Rows": "Zeilen",
"Height": "H\u00f6he",
"Paste row after": "Zeile unterhalb einf\u00fcgen",
"Alignment": "Ausrichtung",
"Column group": "Spaltengruppe",
"Row": "Zeile",
"Insert column before": "Neue Spalte links einf\u00fcgen",
"Split cell": "Verbundene Zellen trennen",
"Cell padding": "Abstand innerhalb der Zellen",
"Cell spacing": "Zellenabstand",
"Row type": "Zeilentyp",
"Insert table": "Tabelle einf\u00fcgen",
"Body": "Tabellenk\u00f6rper",
"Caption": "Beschriftung der Tabelle",
"Footer": "Tabellenfu\u00df",
"Delete row": "Zeile l\u00f6schen",
"Paste row before": "Zeile oberhalb einf\u00fcgen",
"Scope": "Geltungsbereich",
"Delete table": "Tabelle l\u00f6schen",
"H Align": "Ausrichtung H",
"Top": "Oben",
"Header cell": "\u00dcberschrift",
"Column": "Spalte",
"Row group": "Zeilengruppe",
"Cell": "Zelle",
"Middle": "Mitte",
"Cell type": "Zellentyp",
"Copy row": "Zeile kopieren",
"Row properties": "Zeileneigenschaften",
"Table properties": "Tabelleneigenschaften",
"Bottom": "Unten",
"V Align": "Ausrichtung V",
"Header": "Tabellen\u00fcberschrift",
"Right": "Rechts",
"Insert column after": "Neue Spalte rechts einf\u00fcgen",
"Cols": "Spalten",
"Insert row after": "Neue Zeile unterhalb einf\u00fcgen",
"Width": "Breite",
"Cell properties": "Zelleneigenschaften",
"Left": "Links",
"Cut row": "Zeile ausschneiden",
"Delete column": "Spalte l\u00f6schen",
"Center": "Zentriert",
"Merge cells": "Zellen vereinen",
"Insert template": "Vorlage einf\u00fcgen",
"Templates": "Vorlagen",
"Background color": "Hintergrundfarbe",
"Text color": "Textfarbe",
"Show blocks": "Blockelemente einblenden",
"Show invisible characters": "Unsichtbare Zeichen einblenden",
"Words: {0}": "W\u00f6rter: {0}",
"Insert": "Einf\u00fcgen",
"File": "Datei",
"Edit": "Bearbeiten",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Dr\u00fccken Sie ALT-F9 f\u00fcr das Men\u00fc. Dr\u00fccken Sie ALT-F10 f\u00fcr die Werkzeugleiste. Dr\u00fccken Sie ALT-0 f\u00fcr Hilfe",
"Tools": "Extras",
"View": "Ansicht",
"Table": "Tabelle",
"Format": "Format"
});
